==> cds-services-impl-2.7.0-sources.jar: com/sap/cds/services/impl/request/UserInfoFactory.java <==
/**************************************************************************
 * (C) 2019-2024 SAP SE or an SAP affiliate company. All rights reserved. *
 **************************************************************************/
package com.sap.cds.services.impl.request;

import com.sap.cds.services.request.ModifiableUserInfo;
import com.sap.cds.services.request.UserInfo;

public class UserInfoFactory {

	public static ModifiableUserInfo create(UserInfo userInfo) {
		return new ModifiableUserInfoImpl (userInfo != null ? userInfo : anonymousUserInfo());
	}

	// unauthenticated anonymous user
	public static UserInfo anonymousUserInfo() {
		return ANONYMOUS_USER;
	}

	// the privileged user has access in privileged mode (no authorization checks)
	public static UserInfo privilegedUserInfo() {
		return PRIVILEGED_USER;
	}

	public static UserInfo systemUserInfo() {
		return SYSTEM_USER;
	}

	private static UserInfo ANONYMOUS_USER = new UserInfo() {

		@Override
		public String getName() {
			return "anonymous";
		}

		@Override
		public boolean isSystemUser() {
			return false;
		}

		@Override
		public boolean isAuthenticated() {
			return false; // anonymous
		}

	};

	private static UserInfo PRIVILEGED_USER = new UserInfo() {

		@Override
		public String getName() {
			return "privileged";
		}

		@Override
		public boolean isPrivileged() {
			return true;
		}

		// this user will not pass authorization due to following properties (but due to isPrivilegd == true):

		@Override
		public boolean hasRole(String role) {
			return true;
		}

		@Override
		public boolean isSystemUser() {
			return true;
		}

		@Override
		public boolean isAuthenticated() {
			return true;
		}

	};

	private static UserInfo SYSTEM_USER = new UserInfo() {

		@Override
		public String getName() {
			return "system";
		}

		@Override
		public boolean isSystemUser() {
			return true;
		}

		@Override
		public boolean isAuthenticated() {
			return true;
		}
	};
}

==> cds-services-impl-3.7.1-sources.jar: com/sap/cds/services/impl/request/UserInfoFactory.java <==
/**************************************************************************
 * (C) 2019-2024 SAP SE or an SAP affiliate company. All rights reserved. *
 **************************************************************************/
package com.sap.cds.services.impl.request;

import com.sap.cds.services.request.ModifiableUserInfo;
import com.sap.cds.services.request.UserInfo;

public class UserInfoFactory {

	public static ModifiableUserInfo create(UserInfo userInfo) {
		return new ModifiableUserInfoImpl (userInfo != null ? userInfo : anonymousUserInfo());
	}

	// unauthenticated anonymous user
	public static UserInfo anonymousUserInfo() {
		return ANONYMOUS_USER;
	}

	// the privileged user has access in privileged mode (no authorization checks)
	public static UserInfo privilegedUserInfo() {
		return PRIVILEGED_USER;
	}

	public static UserInfo systemUserInfo() {
		return SYSTEM_USER;
	}

	private static UserInfo ANONYMOUS_USER = new UserInfo() {

		@Override
		public String getName() {
			return "anonymous";
		}

		@Override
		public boolean isSystemUser() {
			return false;
		}

		@Override
		public boolean isAuthenticated() {
			return false; // anonymous
		}

	};

	private static UserInfo PRIVILEGED_USER = new UserInfo() {

		@Override
		public String getName() {
			return "privileged";
		}

		@Override
		public boolean isPrivileged() {
			return true;
		}

		// this user will not pass authorization due to following properties (but due to isPrivileged == true):

		@Override
		public boolean hasRole(String role) {
			return true;
		}

		@Override
		public boolean isSystemUser() {
			return true;
		}

		@Override
		public boolean isAuthenticated() {
			return true;
		}

	};

	private static UserInfo SYSTEM_USER = new UserInfo() {

		@Override
		public String getName() {
			return "system";
		}

		@Override
		public boolean isSystemUser() {
			return true;
		}

		@Override
		public boolean isAuthenticated() {
			return true;
		}
	};
}
